var signage = {
  // (A) PROPERTIES
  cname : "scache", // storage cache name
  hslides : null,   // html iframe
  now : 0,          // current slide
  stime : null,     // time to display current slide
  timer : null,     // current slide timer

  // (B) INIT
  init : async () => {
    // (B1) REGISTER SERVICE WORKER
    navigator.serviceWorker.register("worker.js");

    // (B2) GET HTML IFRAME
    signage.hslides = document.getElementById("slides");

    // (B3) "INSTALL" ASSETS CACHE
    if (!await caches.has(signage.cname)) {
      fetch("cache.json")
      .then(r => r.json())
      .then(async f => {
        // (B3-1) ASSETS
        for (let i=0; i<f.length; i++) {
          if (i==0) { continue; }
          f[i] = `assets/${f[i]}`;
        }

        // (B3-2) SLIDES
        localStorage.setItem("slides", f[0]);
        for (let i=1; i<=f[0]; i++) {
          f.push(`slides/${i}.html`);
        }
        f.shift();

        // (B3-3) SIGNAGE APP ITSELF
        f.push(
          "manifest.json",
          "signage.html", "signage.css", "signage.js",
          "assets/favicon.png", "assets/icon-512.png"
        );

        // (B3-4) CREATE CACHE
        (await caches.open(signage.cname)).addAll(f);
        signage.run();
      });
    } else { signage.run(); }
  },

  // (C) RUN SLIDES
  run : () => {
    // (C1) STOP TIMER + NEXT SLIDE
    if (signage.timer) { clearTimeout(signage.timer); }
    signage.now++;
    if (signage.now > localStorage.getItem("slides")) { signage.now = 1; }

    // (C2) ON SLIDE LOAD - START TIMER
    if (localStorage.getItem("slides") > 1) {
      signage.hslides.onload = () => {
        signage.timer = setTimeout(signage.run, signage.stime);
      };
    }

    // (C3) GO!
    signage.hslides.src = `slides/${signage.now}.html`;
  },

  // (D) FLUSH CACHE
  // run this in the console - signage.flush()
  flush : async () => {
    if (await caches.has(signage.cname)) {
      await caches.delete(signage.cname);
    }
  }
};

// (E) INIT SIGNAGE
window.addEventListener("DOMContentLoaded", signage.init);